@@ -62,6 +62,8 @@ def convert(
     keep_shape_absolutely_input_names: Optional[List[str]] = None,
     output_names_to_interrupt_model_conversion: Optional[List[str]] = None,
     disable_group_convolution: Optional[bool] = False,
+    enable_batchmatmul_unfold: Optional[bool] = False,
+    disable_suppression_flextranspose: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_float32: Optional[bool] = False,
     replace_argmax_to_fused_argmax_and_indicies_is_int64: Optional[bool] = False,
@@ -78,6 +80,7 @@ def convert(
     replace_hardswish_to_pseudo_hardswish: Optional[bool] = False,
     replace_erf_to_pseudo_erf: Optional[bool] = False,
     param_replacement_file: Optional[str] = '',
+    check_gpu_delegate_compatibility: Optional[bool] = False,
     mvn_epsilon: Optional[float] = 0.0000000001,
     non_verbose: Optional[bool] = False,
 ) -> tf.keras.Model:
@@ -228,6 +231,12 @@ def convert(
         Disable GroupConvolution and replace it with SeparableConvolution\n
         for output to saved_model format.
 
+    enable_batchmatmul_unfold: Optional[bool]
+        BatchMatMul is separated batch by batch to generate a primitive MatMul.
+
+    disable_suppression_flextranspose: Optional[bool]
+        Disables FlexTranspose generation suppression.
+
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool]
         Replace ArgMax with a ReduceMax. The returned indicies are int64.\n
         Only one of replace_argmax_to_reducemax_and_indicies_is_int64 and \n
@@ -311,6 +320,10 @@ def convert(
     param_replacement_file: Optional[str]
         Parameter replacement file path. (.json)
 
+    check_gpu_delegate_compatibility: Optional[bool]
+        Run TFLite ModelAnalyzer on the generated Float16 tflite model\n
+        to check if the model can be supported by GPU Delegate.'
+
     non_verbose: Optional[bool]
         Do not show all information logs. Only error logs are displayed.\n
         Default: False
@@ -438,26 +451,35 @@ def convert(
                 print(f'{Color.GREEN}Model optimizing complete!{Color.RESET}')
         except Exception as e:
             if not non_verbose:
+                import traceback
+                traceback.print_exc()
                 print(
                     f'{Color.YELLOW}WARNING:{Color.RESET} '+
                     'Failed to optimize the onnx file.'
                 )
-                import traceback
-                traceback.print_exc()
 
     # Automatic generation of each OP name - sng4onnx
     if not not_use_opname_auto_generate:
         if not non_verbose:
             print('')
             print(f'{Color.REVERCE}Automatic generation of each OP name started{Color.RESET}', '=' * 40)
-        op_name_auto_generate(
-            input_onnx_file_path=f'{input_onnx_file_path}',
-            onnx_graph=onnx_graph,
-            output_onnx_file_path=f'{input_onnx_file_path}',
-            non_verbose=True,
-        )
-        if not non_verbose:
-            print(f'{Color.GREEN}Automatic generation of each OP name complete!{Color.RESET}')
+        try:
+            op_name_auto_generate(
+                input_onnx_file_path=f'{input_onnx_file_path}',
+                onnx_graph=onnx_graph,
+                output_onnx_file_path=f'{input_onnx_file_path}',
+                non_verbose=True,
+            )
+            if not non_verbose:
+                print(f'{Color.GREEN}Automatic generation of each OP name complete!{Color.RESET}')
+        except Exception as e:
+            if not non_verbose:
+                import traceback
+                traceback.print_exc()
+                print(
+                    f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                    'Failed to automatic generation of each OP name.'
+                )
 
     # quantization_type
     disable_per_channel = False \
@@ -479,10 +501,12 @@ def convert(
 
     # Define additional parameters
     additional_parameters = {
+        'gs_graph': graph,
         'opset': graph.opset,
         'batch_size': batch_size,
         'non_verbose': non_verbose,
         'disable_group_convolution': disable_group_convolution,
+        'disable_suppression_flextranspose': disable_suppression_flextranspose,
         'replace_argmax_to_reducemax_and_indicies_is_int64': replace_argmax_to_reducemax_and_indicies_is_int64,
         'replace_argmax_to_reducemax_and_indicies_is_float32': replace_argmax_to_reducemax_and_indicies_is_float32,
         'replace_argmax_to_fused_argmax_and_indicies_is_int64': replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -500,6 +524,7 @@ def convert(
         'replace_erf_to_pseudo_erf': replace_erf_to_pseudo_erf,
         'replacement_parameters': replacement_parameters,
         'mvn_epsilon': mvn_epsilon,
+        'output_signaturedefs': output_signaturedefs,
     }
 
     tf_layers_dict = {}
@@ -675,6 +700,7 @@ def convert(
             tf.lite.OpsSet.TFLITE_BUILTINS,
             tf.lite.OpsSet.SELECT_TF_OPS,
         ]
+        converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
         tflite_model = converter.convert()
         with open(f'{output_folder_path}/model_float32.tflite', 'wb') as w:
             w.write(tflite_model)
@@ -693,21 +719,49 @@ def convert(
         if not non_verbose:
             print(f'{Color.GREEN}Float16 tflite output complete!{Color.RESET}')
 
+        # Run TFLite ModelAnalyzer on the generated Float16 tflite model
+        # to check if the model can be supported by GPU Delegate.
+        if check_gpu_delegate_compatibility:
+            print('')
+            try:
+                tf.lite.experimental.Analyzer.analyze(
+                    model_content=tflite_model,
+                    gpu_compatibility=True,
+                )
+            except Exception as ex:
+                if not non_verbose:
+                    import traceback
+                    traceback.print_exc()
+                    print(
+                        f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                        'TFLite ModelAnalyzer failed.'
+                    )
+
         # Quantized TFLite
         if output_integer_quantized_tflite:
             # Dynamic Range Quantization
-            converter.optimizations = [tf.lite.Optimize.DEFAULT]
-            converter.target_spec.supported_types = []
-            converter.target_spec.supported_ops = [
-                tf.lite.OpsSet.TFLITE_BUILTINS,
-                tf.lite.OpsSet.SELECT_TF_OPS,
-            ]
-            converter._experimental_disable_per_channel = disable_per_channel
-            tflite_model = converter.convert()
-            with open(f'{output_folder_path}/model_dynamic_range_quant.tflite', 'wb') as w:
-                w.write(tflite_model)
-            if not non_verbose:
-                print(f'{Color.GREEN}Dynamic Range Quantization tflite output complete!{Color.RESET}')
+            try:
+                converter.optimizations = [tf.lite.Optimize.DEFAULT]
+                converter.target_spec.supported_types = []
+                converter.target_spec.supported_ops = [
+                    tf.lite.OpsSet.TFLITE_BUILTINS,
+                    tf.lite.OpsSet.SELECT_TF_OPS,
+                ]
+                converter._experimental_disable_per_channel = disable_per_channel
+                converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
+                tflite_model = converter.convert()
+                with open(f'{output_folder_path}/model_dynamic_range_quant.tflite', 'wb') as w:
+                    w.write(tflite_model)
+                if not non_verbose:
+                    print(f'{Color.GREEN}Dynamic Range Quantization tflite output complete!{Color.RESET}')
+            except RuntimeError as ex:
+                if not non_verbose:
+                    import traceback
+                    traceback.print_exc()
+                    print(
+                        f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                        'Dynamic Range Quantization tflite output failed.'
+                    )
 
             # Download sample calibration data - MS-COCO x20 images
             # Used only when there is only one input OP, a 4D tensor image,
@@ -769,75 +823,106 @@ def convert(
                     yield calib_data_list
 
             # INT8 Quantization
-            converter.optimizations = [tf.lite.Optimize.DEFAULT]
-            converter.target_spec.supported_ops = [
-                tf.lite.OpsSet.TFLITE_BUILTINS_INT8,
-                tf.lite.OpsSet.SELECT_TF_OPS,
-            ]
-            converter._experimental_disable_per_channel = disable_per_channel
-            converter.representative_dataset = representative_dataset_gen
-            tflite_model = converter.convert()
-            with open(f'{output_folder_path}/model_integer_quant.tflite', 'wb') as w:
-                w.write(tflite_model)
-            if not non_verbose:
-                print(f'{Color.GREEN}INT8 Quantization tflite output complete!{Color.RESET}')
+            try:
+                converter.optimizations = [tf.lite.Optimize.DEFAULT]
+                converter.target_spec.supported_ops = [
+                    tf.lite.OpsSet.TFLITE_BUILTINS_INT8,
+                    tf.lite.OpsSet.SELECT_TF_OPS,
+                ]
+                converter._experimental_disable_per_channel = disable_per_channel
+                converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
+                converter.representative_dataset = representative_dataset_gen
+                tflite_model = converter.convert()
+                with open(f'{output_folder_path}/model_integer_quant.tflite', 'wb') as w:
+                    w.write(tflite_model)
+                if not non_verbose:
+                    print(f'{Color.GREEN}INT8 Quantization tflite output complete!{Color.RESET}')
 
-            # Full Integer Quantization
-            converter.optimizations = [tf.lite.Optimize.DEFAULT]
-            converter.target_spec.supported_ops = [
-                tf.lite.OpsSet.TFLITE_BUILTINS_INT8,
-                tf.lite.OpsSet.SELECT_TF_OPS,
-            ]
-            converter._experimental_disable_per_channel = disable_per_channel
-            converter.representative_dataset = representative_dataset_gen
-            inf_type = None
-            if input_output_quant_dtype == 'int8':
-                inf_type = tf.int8
-            elif input_output_quant_dtype == 'uint8':
-                inf_type = tf.uint8
-            else:
-                inf_type = tf.int8
-            converter.inference_input_type = inf_type
-            converter.inference_output_type = inf_type
-            tflite_model = converter.convert()
-            with open(f'{output_folder_path}/model_full_integer_quant.tflite', 'wb') as w:
-                w.write(tflite_model)
-            if not non_verbose:
-                print(f'{Color.GREEN}Full INT8 Quantization tflite output complete!{Color.RESET}')
+                # Full Integer Quantization
+                converter.optimizations = [tf.lite.Optimize.DEFAULT]
+                converter.target_spec.supported_ops = [
+                    tf.lite.OpsSet.TFLITE_BUILTINS_INT8,
+                    tf.lite.OpsSet.SELECT_TF_OPS,
+                ]
+                converter._experimental_disable_per_channel = disable_per_channel
+                converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
+                converter.representative_dataset = representative_dataset_gen
+                inf_type = None
+                if input_output_quant_dtype == 'int8':
+                    inf_type = tf.int8
+                elif input_output_quant_dtype == 'uint8':
+                    inf_type = tf.uint8
+                else:
+                    inf_type = tf.int8
+                converter.inference_input_type = inf_type
+                converter.inference_output_type = inf_type
+                tflite_model = converter.convert()
+                with open(f'{output_folder_path}/model_full_integer_quant.tflite', 'wb') as w:
+                    w.write(tflite_model)
+                if not non_verbose:
+                    print(f'{Color.GREEN}Full INT8 Quantization tflite output complete!{Color.RESET}')
+            except RuntimeError as ex:
+                if not non_verbose:
+                    import traceback
+                    traceback.print_exc()
+                    print(
+                        f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                        'Full INT8 Quantization tflite output failed.'
+                    )
 
             # Integer quantization with int16 activations
-            converter.optimizations = [tf.lite.Optimize.DEFAULT]
-            converter.target_spec.supported_types = []
-            converter.target_spec.supported_ops = [
-                tf.lite.OpsSet.EXPERIMENTAL_TFLITE_BUILTINS_ACTIVATIONS_INT16_WEIGHTS_INT8,
-                tf.lite.OpsSet.SELECT_TF_OPS,
-            ]
-            converter._experimental_disable_per_channel = disable_per_channel
-            converter.representative_dataset = representative_dataset_gen
-            converter.inference_input_type = tf.float32
-            converter.inference_output_type = tf.float32
-            tflite_model = converter.convert()
-            with open(f'{output_folder_path}/model_integer_quant_with_int16_act.tflite', 'wb') as w:
-                w.write(tflite_model)
-            if not non_verbose:
-                print(f'{Color.GREEN}INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
+            try:
+                converter.optimizations = [tf.lite.Optimize.DEFAULT]
+                converter.target_spec.supported_types = []
+                converter.target_spec.supported_ops = [
+                    tf.lite.OpsSet.EXPERIMENTAL_TFLITE_BUILTINS_ACTIVATIONS_INT16_WEIGHTS_INT8,
+                    tf.lite.OpsSet.SELECT_TF_OPS,
+                ]
+                converter._experimental_disable_per_channel = disable_per_channel
+                converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
+                converter.representative_dataset = representative_dataset_gen
+                converter.inference_input_type = tf.float32
+                converter.inference_output_type = tf.float32
+                tflite_model = converter.convert()
+                with open(f'{output_folder_path}/model_integer_quant_with_int16_act.tflite', 'wb') as w:
+                    w.write(tflite_model)
+                if not non_verbose:
+                    print(f'{Color.GREEN}INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
+            except RuntimeError as ex:
+                if not non_verbose:
+                    import traceback
+                    traceback.print_exc()
+                    print(
+                        f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                        'INT8 Quantization with int16 activations tflite output failed.'
+                    )
 
             # Full Integer quantization with int16 activations
-            converter.optimizations = [tf.lite.Optimize.DEFAULT]
-            converter.target_spec.supported_types = []
-            converter.target_spec.supported_ops = [
-                tf.lite.OpsSet.EXPERIMENTAL_TFLITE_BUILTINS_ACTIVATIONS_INT16_WEIGHTS_INT8,
-                tf.lite.OpsSet.SELECT_TF_OPS,
-            ]
-            converter._experimental_disable_per_channel = disable_per_channel
-            converter.representative_dataset = representative_dataset_gen
-            converter.inference_input_type = tf.int16
-            converter.inference_output_type = tf.int16
-            tflite_model = converter.convert()
-            with open(f'{output_folder_path}/model_full_integer_quant_with_int16_act.tflite', 'wb') as w:
-                w.write(tflite_model)
-            if not non_verbose:
-                print(f'{Color.GREEN}Full INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
+            try:
+                converter.optimizations = [tf.lite.Optimize.DEFAULT]
+                converter.target_spec.supported_types = []
+                converter.target_spec.supported_ops = [
+                    tf.lite.OpsSet.EXPERIMENTAL_TFLITE_BUILTINS_ACTIVATIONS_INT16_WEIGHTS_INT8,
+                    tf.lite.OpsSet.SELECT_TF_OPS,
+                ]
+                converter._experimental_disable_per_channel = disable_per_channel
+                converter._experimental_disable_batchmatmul_unfold = not enable_batchmatmul_unfold
+                converter.representative_dataset = representative_dataset_gen
+                converter.inference_input_type = tf.int16
+                converter.inference_output_type = tf.int16
+                tflite_model = converter.convert()
+                with open(f'{output_folder_path}/model_full_integer_quant_with_int16_act.tflite', 'wb') as w:
+                    w.write(tflite_model)
+                if not non_verbose:
+                    print(f'{Color.GREEN}Full INT8 Quantization with int16 activations tflite output complete!{Color.RESET}')
+            except RuntimeError as ex:
+                if not non_verbose:
+                    import traceback
+                    traceback.print_exc()
+                    print(
+                        f'{Color.YELLOW}WARNING:{Color.RESET} '+
+                        'Full INT8 Quantization with int16 activations tflite output failed.'
+                    )
 
         return model
 
@@ -1059,6 +1144,20 @@ def main():
             'Disable GroupConvolution and replace it with SeparableConvolution \n' +
             'for output to saved_model format.'
     )
+    parser.add_argument(
+        '-ebu',
+        '--enable_batchmatmul_unfold',
+        action='store_true',
+        help=\
+            'BatchMatMul is separated batch by batch to generate a primitive MatMul.'
+    )
+    parser.add_argument(
+        '-dsft',
+        '--disable_suppression_flextranspose',
+        action='store_true',
+        help=\
+            'Disables FlexTranspose generation suppression.'
+    )
     rar_group = parser.add_mutually_exclusive_group()
     rar_group.add_argument(
         '-rari64',
@@ -1199,6 +1298,14 @@ def main():
         default='',
         help='Parameter replacement file path. (.json)'
     )
+    parser.add_argument(
+        '-cgdc',
+        '--check_gpu_delegate_compatibility',
+        action='store_true',
+        help=\
+            'Run TFLite ModelAnalyzer on the generated Float16 tflite model ' +
+            'to check if the model can be supported by GPU Delegate.'
+    )
     parser.add_argument(
         '-n',
         '--non_verbose',
@@ -1250,6 +1357,8 @@ def main():
         keep_shape_absolutely_input_names=args.keep_shape_absolutely_input_names,
         output_names_to_interrupt_model_conversion=args.output_names_to_interrupt_model_conversion,
         disable_group_convolution=args.disable_group_convolution,
+        enable_batchmatmul_unfold=args.enable_batchmatmul_unfold,
+        disable_suppression_flextranspose=args.disable_suppression_flextranspose,
         replace_argmax_to_reducemax_and_indicies_is_int64=args.replace_argmax_to_reducemax_and_indicies_is_int64,
         replace_argmax_to_reducemax_and_indicies_is_float32=args.replace_argmax_to_reducemax_and_indicies_is_float32,
         replace_argmax_to_fused_argmax_and_indicies_is_int64=args.replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -1266,6 +1375,7 @@ def main():
         replace_hardswish_to_pseudo_hardswish=args.replace_hardswish_to_pseudo_hardswish,
         replace_erf_to_pseudo_erf=args.replace_erf_to_pseudo_erf,
         param_replacement_file=args.param_replacement_file,
+        check_gpu_delegate_compatibility=args.check_gpu_delegate_compatibility,
         mvn_epsilon=args.mvn_epsilon,
         non_verbose=args.non_verbose,
     )
