@@ -5,16 +5,22 @@ np.random.seed(0)
 import tensorflow as tf
 import onnx_graphsurgeon as gs
 from onnx2tf.utils.common_functions import (
+    get_replacement_parameter,
+    replace_parameter,
     get_constant_or_variable,
     convert_axis,
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    pre_process_transpose,
+    post_process_transpose,
 )
+from onnx2tf.utils.colors import Color
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -36,19 +42,38 @@ def make_node(
     before_op_output_shape_trans = \
         before_op_output_shape_trans_1
 
-    graph_node_input = get_constant_or_variable(
+    graph_node_input_1 = get_constant_or_variable(
         graph_node.inputs[0],
         before_op_output_shape_trans,
     )
+    graph_node_input_2 = None
+    if len(graph_node.inputs) >= 2:
+        graph_node_input_2 = get_constant_or_variable(
+            graph_node.inputs[1],
+            before_op_output_shape_trans,
+        )
     graph_node_output: gs.Variable = graph_node.outputs[0]
     shape = graph_node_output.shape
     dtype = graph_node_output.dtype
 
-    input_tensor = tf_layers_dict[graph_node_input.name]['tf_node'] \
-        if isinstance(graph_node_input, gs.Variable) else graph_node_input
+    input_tensor = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
+        if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1
     tensor_rank = len(input_tensor.shape)
 
-    axes = graph_node.attrs.get('axes', [])
+    axes = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
+        if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
+    if axes is not None and axes.shape is None:
+        axes = None
+
+    axes = graph_node.attrs.get('axes', axes)
+    noop_with_empty_axes = bool(graph_node.attrs.get('noop_with_empty_axes', 0))
+    if noop_with_empty_axes:
+        error_msg = f'' +\
+            f'{Color.RED}ERROR:{Color.RESET} ' +\
+            f'TensorFlow does not support noop_with_empty_axes=1 (True).'
+        print(error_msg)
+        assert not noop_with_empty_axes, error_msg
+
     if isinstance(axes, list) or (isinstance(axes, np.ndarray) and len(axes.shape) > 0):
         axes = [
             convert_axis(
@@ -63,6 +88,8 @@ def make_node(
             tensor_rank=tensor_rank,
             before_op_output_shape_trans=before_op_output_shape_trans,
         )
+
+    # 0: False, 1: True
     keepdims = bool(graph_node.attrs.get('keepdims', 1))
 
     # Preserving Graph Structure (Dict)
@@ -72,17 +99,47 @@ def make_node(
         'dtype': dtype,
     }
 
+    # Param replacement
+    axes = replace_parameter(
+        value_before_replacement=axes,
+        param_target='attributes',
+        param_name='axes',
+        **kwargs,
+    )
+    keepdims = replace_parameter(
+        value_before_replacement=keepdims,
+        param_target='attributes',
+        param_name='keepdims',
+        **kwargs,
+    )
+
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     # Generation of TF OP
-    axis = list(axes) if axes is not None else None
+    axes = list(axes) if axes is not None else None
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.norm(
             tensor=input_tensor,
-            ord='euclidean',
-            axis=axis,
+            ord=1,
+            axis=axes if len(axes) > 1 else axes[0],
             keepdims=keepdims,
             name=graph_node.name,
         )
 
+    # Post-process transpose
+    tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
         make_tf_node_info(
@@ -91,7 +148,7 @@ def make_node(
                 'tf_inputs': {
                     'tensor': input_tensor,
                     'ord': 'euclidean',
-                    'axis': axis,
+                    'axis': axes,
                     'keepdims': keepdims,
                 },
                 'tf_outputs': {
