@@ -56,16 +56,25 @@ def make_node(
 
     input_tensor = tf_layers_dict[graph_node_input_1.name]['tf_node'] \
         if isinstance(graph_node_input_1, gs.Variable) else graph_node_input_1
-    input_tensor_shape = list(input_tensor.shape)
-    tensor_rank = len(input_tensor_shape)
 
     axes = tf_layers_dict[graph_node_input_2.name]['tf_node'] \
         if isinstance(graph_node_input_2, gs.Variable) else graph_node_input_2
     if axes is not None and axes.shape is None:
         axes = None
-
     axes = graph_node.attrs.get('axes', axes)
 
+    if input_tensor.shape != tf.TensorShape(None):
+        input_tensor_shape = list(input_tensor.shape)
+        tensor_rank = len(input_tensor_shape)
+    elif graph_node_output.shape is not None:
+        input_tensor_shape = [
+            dim for idx, dim in enumerate(graph_node_output.shape) if idx not in axes
+        ]
+        input_tensor_shape = [
+            dim if not isinstance(dim, str) else None for dim in input_tensor_shape
+        ]
+        tensor_rank = len(input_tensor_shape)
+
     if isinstance(axes, list) or (isinstance(axes, np.ndarray) and len(axes.shape) > 0):
         axes = [
             convert_axis(
@@ -86,7 +95,6 @@ def make_node(
         axes.sort()
 
     new_shape = copy.deepcopy(input_tensor_shape)
-    # TODO: Dynamic Tensor
     for idx in axes:
         new_shape.insert(idx, 1)
 
@@ -127,12 +135,23 @@ def make_node(
     test pattern.8 : axes=[3,6], [2,3,4,1,5,6,1,7]
     test pattern.9 : axes=[3,-1], [2,3,4,1,5,6,1,7]
     """
-    tf_layers_dict[graph_node_output.name]['tf_node'] = \
-        tf.reshape(
-            tensor=input_tensor,
-            shape=new_shape,
-            name=graph_node.name,
-        )
+    if len(new_shape) >= 2 \
+        and len([dim for dim in new_shape if dim is None or dim == -1]) >= 2 \
+        and not isinstance(axes, int) \
+        and len(axes) == 1:
+        tf_layers_dict[graph_node_output.name]['tf_node'] = \
+            tf.expand_dims(
+                input=input_tensor,
+                axis=axes[0],
+                name=graph_node.name,
+            )
+    else:
+        tf_layers_dict[graph_node_output.name]['tf_node'] = \
+            tf.reshape(
+                tensor=input_tensor,
+                shape=new_shape,
+                name=graph_node.name,
+            )
 
     # Post-process transpose
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
