@@ -121,9 +121,10 @@ def pre_process_transpose(
             and op_rep_param['param_name'] == param_name:
             transpose_perm = op_rep_param.get('pre_process_transpose_perm', None)
             if transpose_perm is not None:
-                transposed_value = tf.transpose(
-                    a=value_before_transpose,
+                transposed_value = transpose_with_flexing_deterrence(
+                    input_tensor=value_before_transpose,
                     perm=transpose_perm,
+                    **kwargs,
                 )
             break
     return transposed_value
@@ -156,9 +157,10 @@ def post_process_transpose(
             and op_rep_param['param_name'] == param_name:
             transpose_perm = op_rep_param.get('post_process_transpose_perm', None)
             if transpose_perm is not None:
-                transposed_value = tf.transpose(
-                    a=value_before_transpose,
+                transposed_value = transpose_with_flexing_deterrence(
+                    input_tensor=value_before_transpose,
                     perm=transpose_perm,
+                    **kwargs,
                 )
             break
     return transposed_value
@@ -358,7 +360,8 @@ def inverted_operation_enable_disable(func):
 
             trans_judge = (onnx_node_output_shape != tf_node_output_shape)
             # Avoiding patterns of misjudgment when the second and subsequent dimensions are all the same value
-            if len(tf_node_output_shape) >= 3:
+            if tf_node_output_shape != tf.TensorShape(None) \
+                and len(tf_node_output_shape) >= 3:
                 base_shape = tf_node_output_shape[1]
                 if len(tf_node_output_shape)-1 == sum([1 if base_shape == s else 0 for s in tf_node_output_shape[1:]]) \
                     and (onnx_node_output_shape == tf_node_output_shape):
@@ -675,7 +678,9 @@ def broadcast_validity_check(
     """
     result = False
 
-    if len(shape1) != len(shape2):
+    if shape1 is None or shape2 is None:
+        return result
+    elif len(shape1) != len(shape2):
         return result
     else:
         for i, j in zip(shape1, shape2):
@@ -743,6 +748,8 @@ def pre_explicit_broadcast(
             reversed_input_tensor_2_shape = []
             if isinstance(input_tensor_2_shape, list):
                 reversed_input_tensor_2_shape = input_tensor_2_shape.reverse()
+            elif isinstance(input_tensor_2_shape, tuple):
+                reversed_input_tensor_2_shape = list(input_tensor_2_shape[::-1])
             elif isinstance(input_tensor_2_shape, np.ndarray):
                 reversed_input_tensor_2_shape = input_tensor_2_shape[::-1].tolist()
             elif isinstance(input_tensor_2_shape, tf.TensorShape):
@@ -764,6 +771,8 @@ def pre_explicit_broadcast(
                 reversed_input_tensor_1_shape = []
                 if isinstance(input_tensor_1_shape, list):
                     reversed_input_tensor_1_shape = input_tensor_1_shape.reverse()
+                elif isinstance(input_tensor_1_shape, tuple):
+                    reversed_input_tensor_1_shape = list(input_tensor_1_shape[::-1])
                 elif isinstance(input_tensor_1_shape, np.ndarray):
                     reversed_input_tensor_1_shape = input_tensor_1_shape[::-1].tolist()
                 elif isinstance(input_tensor_1_shape, tf.TensorShape):
@@ -810,8 +819,14 @@ def explicit_broadcast(
     if graph_node is not None:
         graph_node_input_name1 = graph_node.inputs[0].name
         graph_node_input_name2 = graph_node.inputs[1].name
-        graph_node_input_shape1 = list(graph_node.inputs[0].shape)
-        graph_node_input_shape2 = list(graph_node.inputs[1].shape)
+        graph_node_input_shape1 = list(graph_node.inputs[0].shape) \
+            if graph_node.inputs[0].shape is not None else None
+        graph_node_input_shape2 = list(graph_node.inputs[1].shape) \
+            if graph_node.inputs[1].shape is not None else None
+
+    # If shape is empty (scalar value), return it without doing anything.
+    if graph_node_input_shape1 == [] or graph_node_input_shape2 == []:
+        return const_or_var_1, const_or_var_2
 
     # If either operand have shape of all 1's, do not broadcast and return as is
     shape_for_judging_skip_processing_1 = [
@@ -831,6 +846,14 @@ def explicit_broadcast(
         graph_node_input_shape1, graph_node_input_shape2 = graph_node_input_shape2, graph_node_input_shape1
         swapped += 1
 
+        # Skip subsequent processing in the following patterns.
+        #   const_or_var_1: [1,1,5000]
+        #   const_or_var_2: [5000]
+        if len(const_or_var_1.shape) >= 1 \
+            and len(const_or_var_2.shape) == 1 \
+            and const_or_var_1.shape[-1] == const_or_var_2.shape[-1]:
+            return const_or_var_1, const_or_var_2
+
     """
     UnSqueeze 1 at the beginning of const_or_var_2_shape until const_or_var_1.shape
     and const_or_var_2.shape have the same rank
@@ -1969,10 +1992,27 @@ def process_neg_idx(
             indices.dtype,
         )
     else:
-        max_i = tf.cast(
-            data_shape[:indices_shape[-1]],
-            indices.dtype,
-        )
+        if not isinstance(indices_shape[-1], int) \
+            and not isinstance(indices_shape[-1], np.ndarray) \
+            and not isinstance(indices_shape[-1], tf.Tensor) \
+            and tf.keras.backend.is_keras_tensor(indices_shape[-1]):
+            if data_shape != tf.TensorShape([None]):
+                max_i = tf.cast(
+                    tf.strided_slice(
+                        input_=data_shape,
+                        begin=0,
+                        end=indices_shape[-1],
+                        begin_mask=1,
+                    ),
+                    indices.dtype,
+                )
+            else:
+                return indices
+        else:
+            max_i = tf.cast(
+                data_shape[:indices_shape[-1]],
+                indices.dtype,
+            )
     return tf.math.floormod(tf.add(indices, max_i), max_i)
 
 
@@ -2068,6 +2108,8 @@ def disable_unnecessary_transpose(
 
         if ((node_x_op_type == 'Transpose' and not node_y_op_type == 'Transpose') \
             or (not node_x_op_type == 'Transpose' and node_y_op_type == 'Transpose')) \
+            and graph_node_input_1.shape is not None \
+            and graph_node_input_2.shape is not None \
             and (len(graph_node_input_1.shape) == len(graph_node_input_2.shape)):
 
             if (node_x_op_type == 'Transpose' and not node_y_op_type == 'Transpose'):
@@ -2150,35 +2192,47 @@ def shape_unmatched_special_avoidance_workaround(
     nhwc_flag_1 = False
     same_input_shape_as_onnx_1 = False
     if isinstance(input_tensor_1, gs.Variable):
-        nhwc_flag_1 =tf_layers_dict[input_tensor_1.name]['nhwc'] \
+        nhwc_flag_1 = tf_layers_dict[input_tensor_1.name]['nhwc'] \
             if 'nhwc' in tf_layers_dict[input_tensor_1.name].keys() else False
-        graph_node_input_1_shape = [
-            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
-        ]
+        if graph_node_input_1.shape is not None:
+            graph_node_input_1_shape = [
+                dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+            ]
+        else:
+            graph_node_input_1_shape = []
         same_input_shape_as_onnx_1 = True if len(graph_node_input_1_shape) > 0 \
             and graph_node_input_1_shape == tf_layers_dict[input_tensor_1.name]['tf_node'].shape else False
     else:
         nhwc_flag_1 = False
-        graph_node_input_1_shape = [
-            dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
-        ]
+        if graph_node_input_1.shape is not None:
+            graph_node_input_1_shape = [
+                dim if not isinstance(dim, str) else None for dim in graph_node_input_1.shape
+            ]
+        else:
+            graph_node_input_1_shape = []
         same_input_shape_as_onnx_1 = True if len(graph_node_input_1_shape) > 0 \
             and graph_node_input_1_shape == input_tensor_1.shape else False
     nhwc_flag_2 = False
     same_input_shape_as_onnx_2 = False
     if isinstance(input_tensor_2, gs.Variable):
-        nhwc_flag_2 =tf_layers_dict[input_tensor_2.name]['nhwc'] \
+        nhwc_flag_2 = tf_layers_dict[input_tensor_2.name]['nhwc'] \
             if 'nhwc' in tf_layers_dict[input_tensor_2.name].keys() else False
-        graph_node_input_2_shape = [
-            dim if not isinstance(dim, str) else None for dim in graph_node_input_2.shape
-        ]
+        if graph_node_input_2.shape is not None:
+            graph_node_input_2_shape = [
+                dim if not isinstance(dim, str) else None for dim in graph_node_input_2.shape
+            ]
+        else:
+            graph_node_input_2_shape = []
         same_input_shape_as_onnx_2 = True if len(graph_node_input_2_shape) > 0 \
             and graph_node_input_2_shape == tf_layers_dict[input_tensor_2.name]['tf_node'].shape else False
     else:
         nhwc_flag_2 = False
-        graph_node_input_2_shape = [
-            dim if not isinstance(dim, str) else None for dim in graph_node_input_2.shape
-        ]
+        if graph_node_input_2.shape is not None:
+            graph_node_input_2_shape = [
+                dim if not isinstance(dim, str) else None for dim in graph_node_input_2.shape
+            ]
+        else:
+            graph_node_input_2_shape = []
         same_input_shape_as_onnx_2 = True if len(graph_node_input_2_shape) > 0 \
             and graph_node_input_2_shape == input_tensor_2.shape else False
 
@@ -2200,20 +2254,58 @@ def shape_unmatched_special_avoidance_workaround(
     return input_tensor_1, input_tensor_2
 
 
-def calc_output_shape_conv_transpose(input_shape, kernel, pad_mode, output_padding, stride, dilation):
+def calc_output_shape_conv_transpose(
+    *,
+    input_shape: List[Any],
+    kernel: List[int],
+    pad_mode: str,
+    output_padding: List[int],
+    stride: List[int],
+    dilation: List[int],
+) -> List[int]:
+    """Calculation of ConvTranspose output geometry.
 
+    Parameters
+    ----------
+    input_shape: List[Any]
+        INPUT Node Shape
+
+    kernel: List[int]
+        kernel size
+
+    pad_mode: str
+        pad mode. "valid" or "same"
+
+    output_padding: List[int]
+        output paddings
+
+    stride: List[int]
+        strides
+
+    dilation: List[int]
+        dilations
+
+    Returns
+    ----------
+    output_shape: List[int]
+        Accurately calculated ConvTranspose output shape
+    """
     assert len(input_shape) == len(kernel) == len(output_padding) == len(stride) == len(dilation),\
         "All parameters should have same length"
 
     output_shape = []
 
     for i, k, p, s, d in zip(input_shape, kernel, output_padding, stride, dilation):
-        output_shape.append(conv_utils.deconv_output_length(input_length=i,
-                                                            filter_size=k,
-                                                            padding=pad_mode.lower(),
-                                                            output_padding=p,
-                                                            stride=s,
-                                                            dilation=d))
+        output_shape.append(
+            conv_utils.deconv_output_length(
+                input_length=i,
+                filter_size=k,
+                padding=pad_mode.lower(),
+                output_padding=p,
+                stride=s,
+                dilation=d,
+            )
+        )
 
     return output_shape
 
@@ -2224,6 +2316,26 @@ def replace_max_values_negative_values(
     index_list: np.asarray,
     axes: np.asarray,
 ) -> List[int]:
+    """Replacement of maximum index value and negative index value for ONNX.
+    For Slice OP.
+
+    Parameters
+    ----------
+    input_tensor_shape: np.asarray
+        INPUT Node Shape
+
+    index_list: np.asarray
+        Index list of starts or ends of Slice OP
+
+    axes: np.asarray
+        Slice OP axes
+
+    Returns
+    ----------
+    index_list: List[int]
+        List of ONNX maximum index values and negative index values replaced
+        with acceptable positive integers
+    """
     if axes is None:
         return index_list
 
@@ -2285,3 +2397,365 @@ def replace_max_values_negative_values(
             if index_list[axis] not in negativevalue_index_dict.keys() \
                 else negativevalue_index_dict[index_list[axis]]
     return index_list
+
+
+def transpose_with_flexing_deterrence(
+    *,
+    input_tensor: Any,
+    perm: List[int],
+    output_shape: List[int] = None,
+    name: str = None,
+    **kwargs: dict,
+) -> Any:
+    """Transpose tensors of 6 or more dimensions while suppressing the transformation to FlexTranspose.
+    Suppress FlexTranspose generation only if the enable_suppression_flextranspose option is enabled when the tool is started.
+
+    Parameters
+    ----------
+    input_tensor: Any
+        Tensor to be transposed
+
+    perm: List[int]
+        inverted perm
+
+    output_shape: List[int]
+        Shape of tensor after transposition.
+        The shape of the tensor in TensorFlow format after transposition must be specified.
+        This value may produce the most optimized Transpose with Special Transpose.1 applied.
+        If this value is not specified, the redundant Special Transpose.2 is applied.
+
+    name: str
+        graph_node.name
+
+    Returns
+    ----------
+    tensor_after_transposition: Any
+        Tensor after transposition
+    """
+    disable_suppression_flextranspose: bool = \
+        kwargs['disable_suppression_flextranspose']
+    tensor_after_transposition = input_tensor
+
+    if disable_suppression_flextranspose:
+        # Normal Transpose
+        tensor_after_transposition = tf.transpose(
+            a=input_tensor,
+            perm=perm,
+            name=name,
+        )
+    else:
+        # Special Transpose
+        # https://zenn.dev/pinto0309/scraps/cfb59856ac0453
+        # Get dimension with 1 element
+        input_tensor_shape: List[int] = input_tensor.shape
+        input_tensor_rank = len(input_tensor_shape)
+        x_shape_one_dims = [
+            idx for idx in range(len(input_tensor_shape)) \
+                if isinstance(input_tensor_shape[idx], int) and input_tensor_shape[idx]==1
+        ]
+        x_shape_none_dims_count = len(
+            [dim for dim in input_tensor_shape if not isinstance(dim, int) or dim < 1]
+        )
+        # Delete dimension with 1 element
+        squeezed_original_x = tf.squeeze(input_tensor, x_shape_one_dims)
+        # Obtain a shape with the dimension with 1 element removed
+        squeezed_original_shapes = squeezed_original_x.shape
+
+        if input_tensor_rank >= 6 \
+            and len(squeezed_original_shapes) <= 5 \
+            and x_shape_none_dims_count < 2 \
+            and output_shape is not None:
+            # Special Transpose.1
+            #   Suppresses as much as possible the conversion of transposes
+            #   of 6 or more dimensions into FlexTransposes.
+            #   Compresses dimensions with a numerical value of 1
+            #   to suppress the generation of redundant Transpose.
+            remove_one_target_perm = [
+                idx for idx in perm if idx not in x_shape_one_dims
+            ]
+            sorted_remove_one_target_perm = sorted(remove_one_target_perm)
+            replaced_remove_one_target_perm = [
+                sorted_remove_one_target_perm.index(idx) \
+                    for idx in remove_one_target_perm
+            ]
+            transposed_no_one_data = \
+                tf.transpose(
+                    a=squeezed_original_x,
+                    perm=replaced_remove_one_target_perm,
+                )
+            tensor_after_transposition = \
+                tf.reshape(
+                    tensor=transposed_no_one_data,
+                    shape=[
+                        dim if not isinstance(dim, str) else -1 for dim in output_shape
+                    ],
+                )
+        elif input_tensor_rank >= 6 and x_shape_none_dims_count == 0:
+            # Special Transpose.2
+            #   Suppresses as much as possible the conversion of transposes
+            #   of 6 or more dimensions into FlexTransposes.
+            #   Decompose and transpose the tensor to be less than 5 dimensions.
+            #   Compress in order from the dimension with the smallest value.
+            #   https://github.com/PINTO0309/onnx2tf/issues/93
+
+            # Overall process flow
+            #   1. Extract the dimension with the smallest number needed to be less than 5 dimensions
+            #   2. Split the tensor in the extracted dimension
+            #   3. Transpose a divided tensor
+            #   4. Concat the transposed tensor
+
+            """
+            e.g.
+                data:
+                    shape = [2,8,8,3,4,5,4,5]
+                    x = torch.arange(1, np.prod(shape)+1)
+                    x = x.reshape(shape)
+                    target_transpose_perm = [6,0,1,4,7,2,5,3]
+
+                result:
+                    shape = [4,2,8,4,5,8,5,3]
+            """
+            # 1. Extract the dimension with the smallest number needed to be less than 5 dimensions
+            np_input_tensor_shape = np.asarray(input_tensor_shape)
+            num_of_dim_requiring_compression = input_tensor_rank - 5
+            """
+            np_input_tensor_shape:
+                Shape of input data before transposition
+                [2, 8, 8, 3, 4, 5, 4, 5]
+
+            sorted_minimum_idxs:
+                List of extracted dimension numbers with small numbers
+                [0, 3, 4]
+
+            removed_split_perm:
+
+                [6, 1, 7, 2, 5]
+
+            target_transpose_perm:
+                perm after transposition
+                [6, 0, 1, 4, 7, 2, 5, 3]
+
+            target_sorted_minimum_idxs:
+                Dimension to be restored at the end of processing
+                [1, 7, 3]
+
+            target_minimum_dims:
+                Number of dimensions to be finally re-expanded
+                [2, 3, 4]
+
+            target_transpose_shape:
+                [4, 2, 8, 4, 5, 8, 5, 3]
+            """
+            sorted_minimum_idxs = np.argsort(np_input_tensor_shape)[:num_of_dim_requiring_compression].tolist()
+            target_minimum_dims = [
+                np_input_tensor_shape[sorted_idx] for sorted_idx in sorted_minimum_idxs
+            ]
+            removed_split_perm = [
+                dim for dim in perm if dim not in sorted_minimum_idxs
+            ]
+            sorted_removed_split_perm = sorted(removed_split_perm)
+            removed_splited_transpose_perm = [
+                sorted_removed_split_perm.index(idx) \
+                    for idx in removed_split_perm
+            ]
+            target_transpose_perm = perm
+            target_sorted_minimum_idxs = [
+                target_transpose_perm.index(idx) for idx in sorted_minimum_idxs
+            ]
+
+            # 2. Split the tensor in the extracted dimension
+            def split_squeeze_tensor(
+                *,
+                input_tensors: List[Any],
+                axis: int,
+            ):
+                result_tensor_list = []
+                for input_tensor in input_tensors:
+                    splited_tensors = tf.split(
+                        value=input_tensor,
+                        num_or_size_splits=input_tensor.shape[axis],
+                        axis=axis,
+                    )
+                    splited_squeezed_tensors = []
+                    for splited_tensor in splited_tensors:
+                        splited_squeezed_tensors.append(
+                            tf.squeeze(
+                                input=splited_tensor,
+                                axis=axis,
+                            )
+                        )
+                    result_tensor_list = result_tensor_list + splited_squeezed_tensors
+                return result_tensor_list
+
+            splited_squeezed_tensors = [input_tensor]
+            axeses = copy.deepcopy(sorted_minimum_idxs)
+            axeses_idx = 0
+            while True:
+                axis = axeses[axeses_idx]
+                splited_squeezed_tensors = split_squeeze_tensor(
+                    input_tensors=splited_squeezed_tensors,
+                    axis=axis,
+                )
+                axeses_idx += 1
+                if axeses_idx > len(axeses)-1:
+                    break
+                new_axeses = []
+                for axes in axeses:
+                    if axes <= axis:
+                        new_axeses.append(axes)
+                    else:
+                        new_axeses.append(axes-1)
+                axeses = new_axeses
+
+            # 3. Transpose a divided tensor (splited_squeezed_tensors)
+            """
+            splited_squeezed_tensors:
+                [
+                    [8, 8, 5, 4, 5],
+                    [8, 8, 5, 4, 5],
+                    [8, 8, 5, 4, 5],
+                            :
+                ]
+
+            shrink_transposed_tensors:
+                [
+                    [4, 8, 5, 8, 5],
+                    [4, 8, 5, 8, 5],
+                    [4, 8, 5, 8, 5],
+                            :
+                ]
+            """
+            shrink_transposed_tensors = []
+            for splited_squeezed_tensor in splited_squeezed_tensors:
+                shrink_transposed_tensors.append(
+                    tf.transpose(
+                        a=splited_squeezed_tensor,
+                        perm=removed_splited_transpose_perm,
+                    )
+                )
+
+            # 4. Concat the transposed tensor
+            """
+            target_sorted_minimum_idxs:
+                [1, 7, 3]
+
+            asc_target_idxs_for_expand:
+                [1, 3, 7]
+
+            target_minimum_dims:
+                [2, 3, 4]
+
+            len(shrink_transposed_tensors):
+                24
+
+            ##########################################
+            shrink_transposed_tensors:
+                [
+                    [4, 8, 5, 8, 5],
+                    [4, 8, 5, 8, 5],
+                    [4, 8, 5, 8, 5],
+                            :
+                ]
+
+            ########################################## step.1 - expand
+            [1, 7, 3] -> [1, 3, 7]
+            shrink_transposed_tensors:
+                [
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                            :
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                ]
+
+            ########################################## step.2 - grouping
+            target_concat_axes: [1, 7, 3] -> [3, 7, 1]
+            gorouping_dims: [2, 3, 4] -> [4, 3, 2]
+            grouped_total_tensors:
+            [
+                [
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                ],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                ],
+                                :
+                [
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                    [4, 1, 8, 1, 5, 8, 5, 1],
+                ],
+            ]
+
+            ########################################## step.3 - concat
+            concated_part_tensors:
+            [
+                [4, 1, 8, 4, 5, 8, 5, 1],
+                [4, 1, 8, 4, 5, 8, 5, 1],
+                            :
+                [4, 1, 8, 4, 5, 8, 5, 1],
+                [4, 1, 8, 4, 5, 8, 5, 1],
+            ]
+
+            ########################################## step.final
+            final_transposed_tensors:
+                [4, 2, 8, 4, 5, 8, 5, 3]
+            """
+
+            ########################################## step.1 - expand
+            asc_target_idxs_for_expand = sorted(target_sorted_minimum_idxs)
+            for target_sorted_minimum_idx in asc_target_idxs_for_expand:
+                transposed_expanded_tensors = []
+                for shrink_transposed_tensor in shrink_transposed_tensors:
+                    transposed_expanded_tensors.append(
+                        tf.expand_dims(
+                            input=shrink_transposed_tensor,
+                            axis=target_sorted_minimum_idx,
+                        )
+                    )
+                shrink_transposed_tensors = transposed_expanded_tensors
+
+            ########################################## step.2 - grouping
+            target_concat_axes = reversed(target_sorted_minimum_idxs)
+            gorouping_dims = reversed(target_minimum_dims)
+            for concat_axis, target_concat_dim in zip(target_concat_axes, gorouping_dims):
+                grouped_part_tensors = []
+                grouped_total_tensors = []
+                for idx, shrink_transposed_tensor in enumerate(shrink_transposed_tensors):
+                    if idx > 0 and (idx % target_concat_dim) == 0:
+                        grouped_total_tensors.append(grouped_part_tensors)
+                        grouped_part_tensors = []
+                    grouped_part_tensors.append(shrink_transposed_tensor)
+                grouped_total_tensors.append(grouped_part_tensors)
+
+                ########################################## step.3 - concat
+                concated_part_tensors = []
+                for tensors in grouped_total_tensors:
+                    concated_part_tensors.append(
+                        tf.concat(
+                            values=tensors,
+                            axis=concat_axis,
+                        )
+                    )
+                shrink_transposed_tensors = concated_part_tensors
+
+            ########################################## step.final
+            tensor_after_transposition = shrink_transposed_tensors[0]
+
+        else:
+            # Normal Transpose
+            tensor_after_transposition = tf.transpose(
+                a=input_tensor,
+                perm=perm,
+                name=name,
+            )
+
+    return tensor_after_transposition
